--- loncom/interface/lonindexer.pm 2013/08/08 14:44:11 1.213.4.5
+++ loncom/interface/lonindexer.pm 2012/07/16 15:30:45 1.216
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Directory Indexer
#
-# $Id: lonindexer.pm,v 1.213.4.5 2013/08/08 14:44:11 raeburn Exp $
+# $Id: lonindexer.pm,v 1.216 2012/07/16 15:30:45 bisitz Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -34,8 +34,9 @@
## 1. Description of functions ##
## 2. Modules used by this module ##
## 3. Choices for different output views (detailed, summary, xml, etc) ##
## 4. Handling routine called via Apache and mod_perl ##
## 5. Other subroutines ##
## ##
###############################################################################
@@ -59,6 +60,7 @@ use LONCAPA qw(:match);
# ---------------------------------------- variables used throughout the module
my %hash; # global user-specific gdbm file
my %dirs; # keys are directories, values are the open/close status
+my %language; # has the reference information present in language.tab
my %dynhash; # hash of hashes for dynamic metadata
my %dynread; # hash of directories already read for dynamic metadata
my %fieldnames; # Metadata fieldnames
@@ -1348,18 +1350,15 @@ sub coursecontext {
my $filesymb=&Apache::lonnet::symbread($filelink);
if ($filesymb) {
my ($map,$index,$resource)=&Apache::lonnet::decode_symb($filesymb);
- $r->print(
- &mt('Already in this course:').'
'
- .&mt('[_1] in folder/map [_2]',
- &Apache::lonnet::gettitle($resource),
- &Apache::lonnet::gettitle($map))
- .'
');
+ $r->print(&mt('Already in this course:
[_1] in folder/map [_2].
',
+ &Apache::lonnet::gettitle($resource),
+ &Apache::lonnet::gettitle($map)));
}
}
sub showpreview {
my ($filelink)=@_;
- if ($filelink=~m-^(/ext/|https?://)-) {
+ if ($filelink=~m-^(/ext/|http://)-) {
return &mt('External Resource, preview not enabled');
}
my ($curfext)=($filelink=~/\.(\w+)$/);
@@ -1490,6 +1489,18 @@ This module enables a scheme of browsing
This is part of the LearningOnline Network with CAPA project
described at http://www.lon-capa.org.
+=head1 BEGIN SUBROUTINE
+
+This routine is only run once after compilation.
+
+=over 4
+
+=item *
+
+Initializes %language hash table.
+
+=back
+
=head1 HANDLER SUBROUTINE
This routine is called by Apache and mod_perl.
@@ -34,8 +34,9 @@
## 2. Modules used by this module ##
## 3. Choices for different output views (detailed, summary, xml, etc) ##
-## 4. Handling routine called via Apache and mod_perl ##
-## 5. Other subroutines ##
+## 4. BEGIN block (to be run once after compilation) ##
+## 5. Handling routine called via Apache and mod_perl ##
+## 6. Other subroutines ##
## ##
###############################################################################